==> wpewebkit_2.32.1.orig.tar.xz: wpewebkit-2.32.1/Source/WebKit/Platform/IPC/MessageFlags.h <==
/*
 * Copyright (C) 2013-2020 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#pragma once

namespace IPC {

enum class MessageFlags : uint8_t {
    DispatchMessageWhenWaitingForSyncReply = 1 << 0,
    DispatchMessageWhenWaitingForUnboundedSyncReply = 1 << 1,
    UseFullySynchronousModeForTesting = 1 << 2,
};

enum class ShouldDispatchWhenWaitingForSyncReply : uint8_t {
    No,
    Yes,
    YesDuringUnboundedIPC,
};

} // namespace IPC

namespace WTF {

template<> struct EnumTraits<IPC::MessageFlags> {
    using values = EnumValues<
        IPC::MessageFlags,
        IPC::MessageFlags::DispatchMessageWhenWaitingForSyncReply,
        IPC::MessageFlags::DispatchMessageWhenWaitingForUnboundedSyncReply,
        IPC::MessageFlags::UseFullySynchronousModeForTesting
    >;
};

} // namespace WTF

==> wpewebkit_2.34.2.orig.tar.xz: wpewebkit-2.34.2/Source/WebKit/Platform/IPC/MessageFlags.h <==
/*
 * Copyright (C) 2013-2020 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#pragma once

namespace IPC {

enum class MessageFlags : uint8_t {
    DispatchMessageWhenWaitingForSyncReply = 1 << 0,
    DispatchMessageWhenWaitingForUnboundedSyncReply = 1 << 1,
    UseFullySynchronousModeForTesting = 1 << 2,
    MaintainOrderingWithAsyncMessages = 1 << 3,
};

enum class ShouldDispatchWhenWaitingForSyncReply : uint8_t {
    No,
    Yes,
    YesDuringUnboundedIPC,
};

} // namespace IPC

namespace WTF {

template<> struct EnumTraits<IPC::MessageFlags> {
    using values = EnumValues<
        IPC::MessageFlags,
        IPC::MessageFlags::DispatchMessageWhenWaitingForSyncReply,
        IPC::MessageFlags::DispatchMessageWhenWaitingForUnboundedSyncReply,
        IPC::MessageFlags::UseFullySynchronousModeForTesting,
        IPC::MessageFlags::MaintainOrderingWithAsyncMessages
    >;
};

} // namespace WTF
